@@ -2,6 +2,7 @@
 
 #include "mountlist.h"
 #include "utils_base.h"
+#include "regex.h"
 
 struct name_list
 {
@@ -20,6 +21,7 @@ struct parameter_list
   thresholds *usedspace_percent;
   thresholds *usedinodes_percent;
   thresholds *freeinodes_percent;
+  char *group;
   struct mount_entry *best_match;
   struct parameter_list *name_next;
 };
@@ -28,5 +30,7 @@ void np_add_name (struct name_list **list, const char *name);
 int np_find_name (struct name_list *list, const char *name);
 int np_seen_name (struct name_list *list, const char *name);
 struct parameter_list *np_add_parameter(struct parameter_list **list, const char *name);
+struct parameter_list *np_find_parameter(struct parameter_list *list, const char *name);
 int search_parameter_list (struct parameter_list *list, const char *name);
 void np_set_best_match(struct parameter_list *desired, struct mount_entry *mount_list, int exact);
+int np_regex_match_mount_entry (struct mount_entry* me, regex_t* re);
