@@ -7,7 +7,7 @@
 *
 * Original author: sean finney
 *
-* Last Modified: $Date: 2006/10/22 22:03:31 $
+* Last Modified: $Date: 2007/01/28 21:46:40 $
 *
 * Description:
 *
@@ -31,12 +31,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_apt.c,v 1.9 2006/10/22 22:03:31 opensides Exp $
+* $Id: check_apt.c,v 1.10 2007/01/28 21:46:40 hweiss Exp $
 * 
 ******************************************************************************/
 
 const char *progname = "check_apt";
-const char *revision = "$Revision: 1.9 $";
+const char *revision = "$Revision: 1.10 $";
 const char *copyright = "2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -201,7 +201,7 @@ int process_arguments (int argc, char **argv) {
 			break;
 		default:
 			/* print short usage statement if args not parsable */
-			usage_va(_("Unknown argument - %s"), optarg);
+			usage5();
 		}
 	}
 
