@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2006/10/19 00:25:16 $
+* Last Modified: $Date: 2007/01/28 21:46:40 $
 *
 * Description:
 *
@@ -30,11 +30,11 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_game.c,v 1.28 2006/10/19 00:25:16 opensides Exp $
+* $Id: check_game.c,v 1.29 2007/01/28 21:46:40 hweiss Exp $
 *****************************************************************************/
 
 const char *progname = "check_game";
-const char *revision = "$Revision: 1.28 $";
+const char *revision = "$Revision: 1.29 $";
 const char *copyright = "2002-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -249,7 +249,7 @@ process_arguments (int argc, char **argv)
         return ERROR;
       break;
     default: /* args not parsable */
-      usage_va(_("Unknown argument - %s"), optarg);
+      usage5();
     }
   }
 
