@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2007/01/28 21:46:40 $
+* Last Modified: $Date: 2007/03/06 22:45:57 $
 *
 * Description:
 *
@@ -33,13 +33,13 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
- $Id: check_http.c,v 1.99 2007/01/28 21:46:40 hweiss Exp $
+ $Id: check_http.c,v 1.101 2007/03/06 22:45:57 tonvoon Exp $
  
 ******************************************************************************/
 /* splint -I. -I../../plugins -I../../lib/ -I/usr/kerberos/include/ ../../plugins/check_http.c */
 
 const char *progname = "check_http";
-const char *revision = "$Revision: 1.99 $";
+const char *revision = "$Revision: 1.101 $";
 const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -175,15 +175,16 @@ process_arguments (int argc, char **argv)
   int option = 0;
   static struct option longopts[] = {
     STD_LONG_OPTS,
-    {"file",required_argument,0,'F'},
     {"link", no_argument, 0, 'L'},
     {"nohtml", no_argument, 0, 'n'},
     {"ssl", no_argument, 0, 'S'},
-    {"verbose", no_argument, 0, 'v'},
     {"post", required_argument, 0, 'P'},
     {"IP-address", required_argument, 0, 'I'},
     {"url", required_argument, 0, 'u'},
+    {"port", required_argument, 0, 'p'},
+    {"authorization", required_argument, 0, 'a'},
     {"string", required_argument, 0, 's'},
+    {"expect", required_argument, 0, 'e'},
     {"regex", required_argument, 0, 'r'},
     {"ereg", required_argument, 0, 'r'},
     {"eregi", required_argument, 0, 'R'},
@@ -1017,7 +1018,7 @@ check_http (void)
         msg = strdup(_("pattern not found"));
       else 
         msg = strdup(_("pattern found"));
-      printf (_("%s - %s%s|%s %s\n"),
+      printf (("%s - %s%s|%s %s\n"),
         _("CRITICAL"),
         msg,
         (display_html ? "</A>" : ""),
@@ -1295,7 +1296,7 @@ print_help (void)
   printf ("    %s\n", _("String to be sent in http header as \"User Agent\""));
   printf (" %s\n", "-k, --header=STRING");
   printf ("    %s\n", _(" Any other tags to be sent in http header. Use multiple times for additional headers"));
-  printf (" %s\n", "-L, --link=URL");
+  printf (" %s\n", "-L, --link");
   printf ("    %s\n", _("Wrap output in HTML link (obsoleted by urlize)"));
   printf (" %s\n", "-f, --onredirect=<ok|warning|critical|follow>");
   printf ("    %s\n", _("How to handle redirected pages"));
