@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2007/02/01 06:53:11 $
+* Last Modified: $Date: 2007/02/14 10:11:06 $
 *
 * Description:
 *
@@ -27,13 +27,13 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_tcp.c,v 1.86 2007/02/01 06:53:11 dermoth Exp $
+* $Id: check_tcp.c,v 1.89 2007/02/14 10:11:06 tonvoon Exp $
 * 
 *****************************************************************************/
 
 /* progname "check_tcp" changes depending on symlink called */
 char *progname;
-const char *revision = "$Revision: 1.86 $";
+const char *revision = "$Revision: 1.89 $";
 const char *copyright = "1999-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -342,7 +342,7 @@ main (int argc, char **argv)
 	/* this is a bit stupid, because we don't want to print the
 	 * response time (which can look ok to the user) if we didn't get
 	 * the response we were looking for. if-else */
-	printf(_("%s %s - "), SERVICE, state_text(result));
+	printf("%s %s - ", SERVICE, state_text(result));
 
 	if(match == -2 && len && !(flags & FLAG_HIDE_OUTPUT))
 		printf("Unexpected response from host/socket: %s", status);
@@ -361,7 +361,7 @@ main (int argc, char **argv)
 		printf (" [%s]", status);
 
 	/* perf-data doesn't apply when server doesn't talk properly,
-	 * so print all zeroes on warn and criti. Use fperfdata since
+	 * so print all zeroes on warn and crit. Use fperfdata since
 	 * localisation settings can make different outputs */
 	if(match == -2)
 		printf ("|%s",
@@ -614,7 +614,7 @@ print_help (void)
 	printf (_(UT_IPv46));
 
 	printf (" %s\n", "-E, --escape");
-  printf ("    %s\n", _("Can use \\n, \\r, \\t or \\ in send or quit string."));
+  printf ("    %s\n", _("Can use \\n, \\r, \\t or \\ in send or quit string. Must come before send or quit option"));
   printf ("    %s\n", _("Default: nothing added to send, \\r\\n added to end of quit"));
   printf (" %s\n", "-s, --send=STRING");
   printf ("    %s\n", _("String to send to the server"));
